import setuptools
setuptools.setup( name='Topsis-Yatin-102003655', version='0.1',
author="yatin goyal", author_email="goyalyatin2002@gmail.com", description="Topsis", packages=setuptools.find_packages(), classifiers=[
"Programming Language :: Python :: 3", "License :: OSI Approved :: MIT License", "Operating System :: OS Independent",
], )